@@ -210,19 +210,19 @@ class Deep_Supervision_UNet3d_Narrow(nn.Module):
     
 
 class Deep_Supervision_UNet3d(nn.Module):
-    def __init__(self, n_modalities = 4, final_output_channels = 5, patch_size = (128, 128, 128), is_binary = False):
+    def __init__(self, in_channels = 1, out_channels = 2, patch_size = (128, 128, 128), is_binary = False):
         super().__init__()
         self.patch_size = np.array(patch_size)
         self.networks_depth = self.get_networks_depth()
         self.encoder_blocks = []
         self.decoder_blocks = []
         self.upsample_operations = []
-        self.final_output_channels = final_output_channels
+        self.final_output_channels = out_channels
         self.is_binary = is_binary
         
         conv_kwargs1 = {'kernel_size' : 3, 'padding' : 1, 'stride' : 1}
         self.encoder1 = nn.Sequential(
-            ConvDropoutNormNonlin(n_modalities, 32, conv_kwargs= conv_kwargs1, conv_op = nn.Conv3d),
+            ConvDropoutNormNonlin(in_channels, 32, conv_kwargs= conv_kwargs1, conv_op = nn.Conv3d),
             ConvDropoutNormNonlin(32, 32, conv_kwargs = conv_kwargs1, conv_op = nn.Conv3d)
         )
         conv_kwargs1 = {'kernel_size' : 3, 'padding' : 1, 'stride' : 2}
@@ -271,16 +271,16 @@ class Deep_Supervision_UNet3d(nn.Module):
         )
 
         self.final_layer1 = nn.Sequential(
-            nn.Conv3d(32, final_output_channels, kernel_size = 1, stride = 1, padding = 0)
+            nn.Conv3d(32, out_channels, kernel_size = 1, stride = 1, padding = 0)
             )
         self.final_layer2 = nn.Sequential(
-            nn.Conv3d(64, final_output_channels, kernel_size = 1, stride = 1, padding = 0)
+            nn.Conv3d(64, out_channels, kernel_size = 1, stride = 1, padding = 0)
             )
         self.final_layer3 = nn.Sequential(
-            nn.Conv3d(128, final_output_channels, kernel_size = 1, stride = 1, padding = 0)
+            nn.Conv3d(128, out_channels, kernel_size = 1, stride = 1, padding = 0)
             )
         self.final_layer4 = nn.Sequential(
-            nn.Conv3d(256, final_output_channels, kernel_size = 1, stride = 1, padding = 0)
+            nn.Conv3d(256, out_channels, kernel_size = 1, stride = 1, padding = 0)
             )
 
         self.upsample4 = nn.Upsample(scale_factor=8, mode = 'trilinear')
